@@ -3,24 +3,31 @@ sysinfo.py [host1] [host2] [options]
 
 obtain system info from remote machine.
 
-(c) Holger Krekel, GPLv2 or 3
+(c) Holger Krekel, MIT license
 """
 
+import optparse
 import py
+import re
 import sys
 import execnet
 
 
-parser = py.std.optparse.OptionParser(usage=__doc__)
-parser.add_option("-f", "--sshconfig", action="store", dest="ssh_config", default=None,
-                  help="use given ssh config file, and add info all contained hosts for getting info")
-parser.add_option("-i", "--ignore", action="store", dest="ignores", default=None,
-                  help="ignore hosts (useful if the list of hostnames come from a file list)")
+parser = optparse.OptionParser(usage=__doc__)
+parser.add_option(
+    "-f", "--sshconfig", action="store", dest="ssh_config", default=None,
+    help="use given ssh config file,"
+         " and add info all contained hosts for getting info")
+parser.add_option(
+    "-i", "--ignore", action="store", dest="ignores", default=None,
+    help="ignore hosts "
+         "(useful if the list of hostnames come from a file list)")
+
 
 def parsehosts(path):
     path = py.path.local(path)
     l = []
-    rex = py.std.re.compile(r'Host\s*(\S+)')
+    rex = re.compile(r'Host\s*(\S+)')
     for line in path.readlines():
         m = rex.match(line)
         if m is not None:
@@ -28,6 +35,7 @@ def parsehosts(path):
             l.append(sshname)
     return l
 
+
 class RemoteInfo:
     def __init__(self, gateway):
         self.gw = gateway
@@ -44,7 +52,7 @@ class RemoteInfo:
         return self.exreceive("""
             import %s
             channel.send(%s)
-        """ %(module, modpath))
+        """ % (module, modpath))
 
     def islinux(self):
         return self.getmodattr('sys.platform').find("linux") != -1
@@ -57,7 +65,7 @@ class RemoteInfo:
 
     def getmemswap(self):
         if self.islinux():
-            return self.exreceive("""
+            return self.exreceive(r"""
             import commands, re
             out = commands.getoutput("free")
             mem = re.search(r"Mem:\s+(\S*)", out).group(1)
@@ -90,16 +98,20 @@ class RemoteInfo:
                 channel.send((numcpus, model))
             """)
 
+
 def debug(*args):
     print >>sys.stderr, " ".join(map(str, args))
+
+
 def error(*args):
     debug("ERROR", args[0] + ":", *args[1:])
 
+
 def getinfo(sshname, ssh_config=None, loginfo=sys.stdout):
-    import execnet
-    spec = "ssh=%s" % sshname
     if ssh_config:
-        spec += "ssh_config=%s" % ssh_config
+        spec = "ssh=-F {} {}".format(ssh_config, sshname)
+    else:
+        spec += "ssh=%s" % sshname
     debug("connecting to", repr(spec))
     try:
         gw = execnet.makegateway(spec)
@@ -107,14 +119,14 @@ def getinfo(sshname, ssh_config=None, loginfo=sys.stdout):
         error("could not get sshgatway", sshname)
     else:
         ri = RemoteInfo(gw)
-        #print "%s info:" % sshname
+        # print "%s info:" % sshname
         prefix = sshname.upper() + " "
         print >>loginfo, prefix, "fqdn:", ri.getfqdn()
         for attr in (
             "sys.platform",
             "sys.version_info",
         ):
-            loginfo.write("%s %s: " %(prefix, attr,))
+            loginfo.write("{} {}: ".format(prefix, attr))
             loginfo.flush()
             value = ri.getmodattr(attr)
             loginfo.write(str(value))
@@ -122,7 +134,7 @@ def getinfo(sshname, ssh_config=None, loginfo=sys.stdout):
             loginfo.flush()
         memswap = ri.getmemswap()
         if memswap:
-            mem,swap = memswap
+            mem, swap = memswap
             print >>loginfo, prefix, "Memory:", mem, "Swap:", swap
         cpuinfo = ri.getcpuinfo()
         if cpuinfo:
@@ -143,4 +155,3 @@ if __name__ == '__main__':
     for host in hosts:
         if host not in ignores:
             getinfo(host, ssh_config=ssh_config)
-
