@@ -2,6 +2,7 @@
     tests for multi channels and gateway Groups
 """
 
+import gc
 import pytest
 from time import sleep
 import execnet
@@ -152,9 +153,9 @@ class TestGroup:
         assert len(gwlist) == 3
         idlist = [x.id for x in gwlist]
         assert idlist == list('325')
-        print (group)
+        print(group)
         group.terminate()
-        print (group)
+        print(group)
         assert not group
         assert repr(group) == "<Group []>"
 
@@ -175,14 +176,17 @@ class TestGroup:
         group = Group()
         gw = group.makegateway("popen//id=hello")
         assert group["hello"] == gw
-        py.test.raises((TypeError, AttributeError), "del group['hello']")
-        py.test.raises((TypeError, AttributeError), "group['hello'] = 5")
+        with pytest.raises((TypeError, AttributeError)):
+            del group['hello']
+        with pytest.raises((TypeError, AttributeError)):
+            group['hello'] = 5
         assert 'hello' in group
         assert gw in group
         assert len(group) == 1
         gw.exit()
         assert 'hello' not in group
-        py.test.raises(KeyError, "group['hello']")
+        with pytest.raises(KeyError):
+            _ = group['hello']
 
     def test_default_group(self):
         oldlist = list(execnet.default_group)
@@ -212,7 +216,6 @@ class TestGroup:
         group.terminate(1.0)
 
 
-@pytest.mark.skipif("sys.version_info < (2,6)")
 def test_safe_terminate(execmodel):
     if execmodel.backend != "threading":
         pytest.xfail("execution model %r does not support task count" %
@@ -222,18 +225,17 @@ def test_safe_terminate(execmodel):
     l = []
 
     def term():
-        py.std.time.sleep(3)
+        sleep(3)
 
     def kill():
         l.append(1)
     safe_terminate(execmodel, 1, [(term, kill)] * 10)
     assert len(l) == 10
     sleep(0.1)
-    py.std.gc.collect()
+    gc.collect()
     assert execmodel.active_count() == active
 
 
-@pytest.mark.skipif("sys.version_info < (2,6)")
 def test_safe_terminate2(execmodel):
     if execmodel.backend != "threading":
         pytest.xfail("execution model %r does not support task count" %
@@ -250,5 +252,5 @@ def test_safe_terminate2(execmodel):
     safe_terminate(execmodel, 3, [(term, kill)] * 10)
     assert len(l) == 0
     sleep(0.1)
-    py.std.gc.collect()
+    gc.collect()
     assert threading.active_count() == active
